@@ -3,7 +3,6 @@ from os import system
 import boto3
 
 from gevault.lib.vault import Vault
-from gevault.lib.refresh import Refresh
 from gevault.lib.tester_stack.stack import Stack
 
 DEFAULT_STACK_NAME = "GEVault-Test-Server"
@@ -30,7 +29,20 @@ class Test(Vault):
             "SubnetId": subnet_id
         }
         self.stack.set_parameters(parameters)
-        self.stack.push()
+        self.stack.push(stack_type="user_data")
+
+    def nat_stack(self):
+
+        (subnet_id, vpc_id) = self.__get_subnet_info()
+        ami_id = input("AWS AMI ID: ")
+
+        parameters = {
+            "AmiId": ami_id,
+            "VpcId": vpc_id,
+            "SubnetId": subnet_id
+        }
+        self.stack.set_parameters(parameters)
+        self.stack.push(stack_type="nat")
 
     def connect(self):
         outputs = self.stack.get_outputs()
@@ -44,6 +56,18 @@ class Test(Vault):
         self._whisper("Running command: %s" % command)
         system(command)
 
+    def connect_nat(self):
+        outputs = self.stack.get_outputs()
+        try:
+            ip_address = outputs["VaultTestPrivateIP"]
+        except KeyError:
+            raise Exception("IP Address of Server could not be found in stack.  Make sure to `push_stack` before connecting.")
+        key_name = self._get_key_name()
+        ssh_loc = expanduser("~/.ssh")
+        command = "ssh gecloud@%s -i %s/%s" % (ip_address, ssh_loc, key_name)
+        self._whisper("Running command: %s" % command)
+        system(command)        
+
     def __get_stack_name(self):
         if not self.config.get("testStack", {}).get("stackName", None):
             stack_name = input("Stack Name (default: %s): " % DEFAULT_STACK_NAME)
