@@ -1,4 +1,4 @@
-from lib.vault import Vault
+from gevault.lib.vault import Vault
 
 class Users(Vault):
 
